Utah Courts - Utah Supreme Court Opinions
Description: Utah State Courts public website. Information regarding court locations, rules, opinions, how-to guides, and additional infomation from the Utah State Courts system.
Keywords: Utah State Courts, Utah, State, Courts, Divorce, Utah Divorce, Online Divorce, Legal Assistance,Pro Se Divorce, Pro Se, Divorce, custody,jury, Jury service, Legal, opinions,Utah Supreme Court,District Court,Juvenile Court,rules,forms,resources,how to guides,how to, guides, fines,bail amounts, judges, Mediation, Utah Mediation,

UTAH COURTS

## Supreme Court Opinions By Date - 2014

Back to Appellate Court Opinions

State v. Lucero, No. 20090751, Filed May 13, 2014, 2014 UT 15

Dillon v. Southern Management, No. 20120145, Filed May 13, 2014, 2014 UT 14 AMENDED OPINION

Energy Claims v. Catalyst Investment, No. 20120156, Filed May 9, 2014, 2014 UT 13

Dillon v. Southern Management, No. 20120145, Filed May 2, 2014, 2014 UT 12 AMENDED May 13, 2013

State v. Gutierrez-Perez, No. 20120455, Filed April 29, 2014, 2014 UT 11

State v. Nielsen, No. 20080709, Filed April 29, 2014, 2014 UT 10

Baird v. Baird, No. 20120488, Filed March 7, 2014, 2014 UT 8

State of Utah v. Manatau, No. 20100908, Filed March 7, 2014, 2014 UT 7

Carlton v. Brown, No. 20120268, Filed February 25, 2014, 2014 UT 6

Ramsay v. Kane County, No. 20120349, Filed February 25, 2014, 2014 UT 5

State v. Bagnes, No. 20100882, Filed February 7, 2014, 2014 UT 4

Hughes v. Utah Labor Commission, No. 20120426, Filed January 31, 2014, 2014 UT 3

MacGregor v. Walker, et al., No. 20120452, Filed January 28, 2014, 2014 UT 2

State v. Bedell, No. 20120692, Filed January 24, 2014, 2014 UT 1

Page Last Modified: 5/13/2014
Return to Top